==> jc-1.4.0.tar.gz: soot/jimple/toolkits/graph/CriticalEdgeRemover.h <==
// public class soot.jimple.toolkits.graph.CriticalEdgeRemover

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 2fe5e781161305e9 soot_jimple_toolkits_graph_CriticalEdgeRemover

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_graph_CriticalEdgeRemover_H_
#define _JC_soot_jimple_toolkits_graph_CriticalEdgeRemover_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object;
struct _jc_soot_util_Chain$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$sub_refs	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$sub_refs;
typedef struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$sub_nonrefs	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$refs	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$refs;
typedef struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$nonrefs	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$nonrefs;
typedef struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object;

typedef const struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vmethods	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vmethods;
typedef const struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtable	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtable;
typedef const struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtype	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method$removeCriticalEdges$a8093fff7e3157aa(_jc_env *, struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object *, struct _jc_soot_Body$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method_info$removeCriticalEdges$a8093fff7e3157aa;

// Static methods
extern struct _jc_object *_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method$insertGotoAfter$537b4d5de684e9f2(_jc_env *, struct _jc_object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method$insertGotoBefore$df13c29d73535174(_jc_env *, struct _jc_object *, struct _jc_object *, struct _jc_object *);
extern void _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method$redirectBranch$2322c95a5a0a6156(_jc_env *, struct _jc_object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object *_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method$v$7e26187433bbb910(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	void	(*removeCriticalEdges$a8093fff7e3157aa)(_jc_env *, struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object *, struct _jc_soot_Body$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vmethods	soot_jimple_toolkits_graph_CriticalEdgeRemover;
};

// Vtype
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$refs {
    _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$sub_refs	soot_jimple_toolkits_graph_CriticalEdgeRemover;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$sub_nonrefs	soot_jimple_toolkits_graph_CriticalEdgeRemover;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object {
	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtype	*vtype;
	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtype _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_graph_CriticalEdgeRemover, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$class_object;

#endif	/* _JC_soot_jimple_toolkits_graph_CriticalEdgeRemover_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/graph/CriticalEdgeRemover.h <==
// public class soot.jimple.toolkits.graph.CriticalEdgeRemover

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 2fe5e781161305e9 soot_jimple_toolkits_graph_CriticalEdgeRemover

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_graph_CriticalEdgeRemover_H_
#define _JC_soot_jimple_toolkits_graph_CriticalEdgeRemover_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object;
struct _jc_soot_util_Chain$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$sub_refs	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$sub_refs;
typedef struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$sub_nonrefs	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$refs	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$refs;
typedef struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$nonrefs	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$nonrefs;
typedef struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object;

typedef const struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vmethods	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vmethods;
typedef const struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtable	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtable;
typedef const struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtype	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method$removeCriticalEdges$a8093fff7e3157aa(_jc_env *, struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method_info$internalTransform$9abd4924859b68a3;
extern _jc_method _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method_info$removeCriticalEdges$a8093fff7e3157aa;

// Static methods
extern struct _jc_object *_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method$insertGotoAfter$537b4d5de684e9f2(_jc_env *, struct _jc_object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method$insertGotoBefore$df13c29d73535174(_jc_env *, struct _jc_object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method$redirectBranch$2322c95a5a0a6156(_jc_env *, struct _jc_object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object *_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$method$v$7e26187433bbb910(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*removeCriticalEdges$a8093fff7e3157aa)(_jc_env *, struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object *, struct _jc_soot_Body$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vmethods	soot_jimple_toolkits_graph_CriticalEdgeRemover;
};

// Vtype
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$refs {
    _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$sub_refs	soot_jimple_toolkits_graph_CriticalEdgeRemover;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$sub_nonrefs	soot_jimple_toolkits_graph_CriticalEdgeRemover;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$object {
	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtype	*vtype;
	_jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$vtype _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_graph_CriticalEdgeRemover, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_graph_CriticalEdgeRemover$class_object;

#endif	/* _JC_soot_jimple_toolkits_graph_CriticalEdgeRemover_H_ */
